@@ -4,11 +4,6 @@
 #' modified Fitch algorithm presented in 
 #' \insertCite{Brazeau2019;textual}{TreeSearch}.
 #' 
-#TODO November 2021: REMOVE next para
-#' Correct colouration of internal nodes requires "ape" version 5.5.2.
-#' Until this is available on CRAN (expected in winter 2021), download it
-#' using `devtools::install_github('emmanuelparadis/ape')`.
-#' 
 #' @template treeParam
 #' @template datasetParam
 #' @param char Index of character to plot.
@@ -50,7 +45,7 @@
 #' @template MRS
 #' @importFrom ape plot.phylo nodelabels 
 #' @importFrom graphics par
-#' @importFrom TreeTools Postorder
+#' @importFrom TreeTools PostorderOrder
 #' @export
 PlotCharacter <- function (tree, dataset, char = 1L,
                            updateTips = FALSE,
@@ -78,14 +73,14 @@ PlotCharacter <- function (tree, dataset, char = 1L,
   dataset <- dataset[treeTaxa]
   
   # Read tree
-  edgeLength <- tree$edge.length
-  tree <- Postorder(tree)
+  postorder <- PostorderOrder(tree)
+  edgeLength <- tree$edge.length[postorder]
   if (!is.null(edgeLength) && length(unique(edgeLength)) == 1) {
     tree$edge.length <- edgeLength
   }
   nNode <- tree$Nnode
   nTip <- NTip(tree)
-  edge <- tree$edge
+  edge <- tree$edge[postorder, ]
   parent <- edge[, 1]
   child <- edge[, 2]
   left <- integer(nNode + nTip)
@@ -101,8 +96,8 @@ PlotCharacter <- function (tree, dataset, char = 1L,
       right[pa] <- ch
     }
   }
-  postOrderNodes <- unique(parent)
-  preOrderNodes <- rev(postOrderNodes)
+  preOrderNodes <- unique(rev(parent)) # Root guaranteed first
+  postOrderNodes <- rev(preOrderNodes)
   rootNode <- preOrderNodes[1]
   parentOf[rootNode] <- rootNode
   tips <- seq_len(nTip)
