@@ -1,5 +1,5 @@
 test_that("IW Scoring", {
-  library('TreeTools', quietly = TRUE, warn.conflicts = FALSE)
+  library('TreeTools', quietly = TRUE)
   data('Lobo', package = 'TreeTools')
   dataset <- Lobo.phy
   tree <- NJTree(dataset)
@@ -57,4 +57,4 @@ test_that("IW Scoring", {
   expect_equal(Inf, morphy_iw(edge, morphyObjects, weight, minLength, charSeq,
                               concavity, 0))
   
-})
\ No newline at end of file
+})
